#!/usr/bin/perl -w

#------------------------------------------------------------------------------
#                  GEOS-Chem Global Chemical Transport Model                  !
#------------------------------------------------------------------------------
#BOP
#
# !IROUTINE: job_depend.pl
#
# !DESCRIPTION: Submits several jobs to the SLURM scheduler, such that
#  each job will wait for the previous job to be done.  Handy for
#  submitting stages of long model runs.
#\\
#\\
# !REMARKS:
#  Add the job script names to the @jobs array.
#
# !REVISION HISTORY:
#  16 Mar 2018 - R. Yantosca - Initial version
#EOP
#------------------------------------------------------------------------------
#BOC
#
# !LOCAL VARIABLES:
#

# Scalars
my $count   = 0;

# Strings
my $depend = "";
my $result = "";
my $job    = "";
my $jobId  = "";

# Arrays
my @subStr = ();
my @jobs   = qw/GCC_13.0.0.201102
                GCC_13.0.0.201103
                GCC_13.0.0.201104
                GCC_13.0.0.201105
                GCC_13.0.0.201106
                GCC_13.0.0.201107
                GCC_13.0.0.201108
                GCC_13.0.0.201109
                GCC_13.0.0.201110
                GCC_13.0.0.201111
                GCC_13.0.0.201112
                GCC_13.0.0.201201
                GCC_13.0.0.201202
                GCC_13.0.0.201203
                GCC_13.0.0.201204
                GCC_13.0.0.201205
                GCC_13.0.0.201206
                GCC_13.0.0.201207
                GCC_13.0.0.201208
                GCC_13.0.0.201209
                GCC_13.0.0.201210
                GCC_13.0.0.201211
                GCC_13.0.0.201212/;

# Loop over jobs
foreach $job ( @jobs ) {

  # Add the dependency string after the first job is submitted
  # (On the first pass, it's a blank string)
  if ( $count > 0 ) { $depend = "--dependency=afterok:$jobId "; }

  # Submit the job
  $cmd    = "sbatch $depend $job";
  print "$cmd\n";
  $result = qx/$cmd/;
  print "$result";

  # The job ID Is the last substring 
  @subStr = split( ' ', $result );
  $jobId  = $subStr[3];
  
  # Increment count
  $count++;
}

exit( $? );
